AUTHORITATIVE_MARKERS = [
    "you must", "i decide", "final decision",
    "mandatory", "required", "directive",
    "this will be done"
]

COLLABORATIVE_MARKERS = [
    "we should", "let us", "let's",
    "together", "team", "collaborate",
    "discuss", "align", "consensus"
]
AUTHORITATIVE_INTENT_VERBS = [
    "mandatory",
    "required",
    "require",
    "directive",
    "decide",
    "final",
    "must"
]


def authoritative_rule(text: str) -> int:
    """
    Returns:
        1 -> Authoritative
        0 -> Collaborative
    """
    t = text.lower()

    for m in COLLABORATIVE_MARKERS:
        if m in t:
            return 0

    for m in AUTHORITATIVE_MARKERS:
        if m in t:
            return 1

    return 0
