NARRATIVE_MARKERS = [
    "then", "after", "before", "when",
    "later", "earlier", "suddenly",
    "eventually", "once", "while"
]

EXPLANATORY_MARKERS = [
    "explains", "describes", "refers to",
    "defined as", "consists of",
    "is used to", "means that"
]


def narrative_rule(text: str) -> int:
    """
    Returns:
        1 -> Narrative
        0 -> Explanatory
    """
    t = text.lower()

    for m in NARRATIVE_MARKERS:
        if m in t:
            return 1

    for m in EXPLANATORY_MARKERS:
        if m in t:
            return 0

    # default to explanatory
    return 0
