from tone.fusion.fused_classifier import FusedClassifier


ASSERTIVE_MARKERS = [
    "must", "need to", "do this", "do it",
    "ensure", "make sure", "required",
    "will be done"
]

SUBMISSIVE_MARKERS = [
    "maybe", "perhaps", "i think", "i guess",
    "could you", "would you",
    "if you don't mind", "sorry"
]
ASSERTIVE_INTENT_VERBS = [
    "must",
    "need",
    "require",
    "required",
    "ensure",
    "make sure"
]


def assertive_rule(text: str) -> int:
    """
    Returns:
        1 -> Assertive
        0 -> Submissive
    """
    t = text.lower()

    for m in SUBMISSIVE_MARKERS:
        if m in t:
            return 0

    for m in ASSERTIVE_MARKERS:
        if m in t:
            return 1

    return 0
